%global _python_bytecompile_errors_terminate_build 0
#https://github.com/frappe/frappe/issues/901
%global project frappe

Name:             python-%project
Version:          5.3.0
Release:          2%{?dist}
Summary:          Meta data driven web framework
License:          MIT
URL:              http://frappe.io/
Group:            Development/Libraries
Source0:          https://github.com/%project/%project/archive/v%version.tar.gz
Source1:          frappe.service
Source2:          README.fedora

BuildArch:        noarch
# Exclusive archs must match nodejs
ExclusiveArch: %{ix86} x86_64 %{arm} noarch

BuildRequires:    python
BuildRequires:    python2-devel
BuildRequires:    python-setuptools
BuildRequires:    systemd
BuildRequires:    nodejs-packaging

Requires:         python-frappe-libs
Requires(pre):    shadow-utils
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

#In dockerland these services can run in theirs own containers.
Recommends:       redis
Recommends:       nginx

Enhances:         python-werkzeug-docs
Enhances:         python-gunicorn-doc
Enhances:         babel-doc
Enhances:         python-frappe-doc

%description
Frappe is a full stack web application framework built on Python 
and MariaDb. It is meta-data driven and has a rich web interface 
and most features you would expect from a web framework. 
This package provide systemd unit for production 

%package libs
Summary: Python libraries to delevop apps with Frappe
Group: Development/Libraries
Requires:         babel
Requires:         ipython
Requires:         open-sans-fonts
Requires:         python-click
Requires:         python-cssmin
Requires:         python-dateutil
Requires:         python-dropbox
Requires:         python-email_reply_parser
Requires:         python-frappe-filesystem
Requires:         python-frappe-bench
Requires:         python-geoip-geolite2
Requires:         python-gunicorn
Requires:         python-html2text
Requires:         python-markdown2
Requires:         python-mysql
Requires:         python-num2words
Requires:         python-pdfkit
Requires:         python-redis
Requires:         python-selenium
Requires:         python-semantic_version
Requires:         python-slugify
Requires:         python-termcolor
Requires:         python-xhtml2pdf
Requires:         python-werkzeug
Requires:         npm(Flot)
#Requires:         npm(prismjs)
#https://bugzilla.redhat.com/show_bug.cgi?id=1246720
Requires:         npm(js-beautify)
#Frappe support to host mariadb in a second server
Recommends:       mariadb-server

%description libs
Python libraries to delevop apps with Frappe and MariaDB. 
This package provides the Frappe Framework and the Bench 
command line tool to create Frappe based apps and start Frappe 
in developer mode.

%package doc
Summary: Documentation for %{name}
Group: Documentation

%description doc
Documentation for %{name}.

%package filesystem
Summary:        Filesystem for Frappe Apps

%description filesystem
System directories for Frappe apps.

%prep
%setup -q -n %project-%version
rm -rf %{name}.egg.info

#Remove hidden file
rm %{_builddir}/%project-%version/%project/templates/emails/.txt

#Make this file as not executables
find %{_builddir}/%{project}-%{version} -name '*.js' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.svg' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.css' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.md' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.txt' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.scss' \
  -exec chmod 644 {} \;

find %{_builddir}/%{project}-%{version} -name '*.less' \
  -exec chmod 644 {} \;

#Fix shebang
sed -i '1{\@^#!/usr/bin/env python@d}' %{_builddir}/%{project}-%{version}/frappe/pythonrc.py

#Remove bundled .js
rm -rf frappe/public/js/lib/flot
rm -f frappe/public/js/lib/prism.js
rm -f frappe/public/js/lib/beautify-html.js

%build
%py2_build

%install
%py2_install

#Link .js libraries
ln -sf %{nodejs_sitelib}/flot %{buildroot}/%{python2_sitelib}/frappe/public/js/lib/flot

ln -sf %{nodejs_sitelib}/prismjs/prism.js %{buildroot}/%{python2_sitelib}/frappe/public/js/lib/prism.js

ln -sf %{nodejs_sitelib}/js-beautify/lib/beautify-html.js  %{buildroot}/%{python2_sitelib}/frappe/public/js/lib/beautify-html.js

#Create required filesystem schema
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench/apps
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench/config
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench/logs
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench/sites

#Link from python site libs
ln -sf %{python2_sitelib}/%project \
${RPM_BUILD_ROOT}%{_localstatedir}/frappe-bench/apps/frappe

install -Dp -m0644 %{SOURCE1} ${RPM_BUILD_ROOT}%{_unitdir}/frappe.service

install -m 644  %{SOURCE2} .

%pre
getent group frappe >/dev/null || groupadd -r frappe
getent passwd frappe >/dev/null || \
    useradd -r -g frappe -d /var/frappe-bench -s /sbin/nologin \
    -c "Frappe user to avoid run as root" frappe
exit 0

%post
%systemd_post frappe.service

%preun
%systemd_preun frappe.service

%postun
%systemd_postun_with_restart frappe.service 

%files
%doc README.md README.fedora
%{_unitdir}/*

%files libs
%{python2_sitelib}/%project
%{python2_sitelib}/%project-%{version}-py?.?.egg-info
%{_localstatedir}/frappe-bench/apps/frappe
#Exclude zero-length files
%exclude %{python2_sitelib}/%project/translations/en.csv
%exclude %{python2_sitelib}/%project/public/css/font/open-sans/OpenSans-Semibold-webfont.ttf
%exclude %{python2_sitelib}/%project/translations/is.csv
%exclude %{python2_sitelib}/%project/public/css/mixins.css
%exclude %{python2_sitelib}/%project/templates/includes/footer/footer_extension.html

%files filesystem
%license license.txt
%dir %attr(755, frappe, frappe) %{_localstatedir}/frappe-bench
%dir %attr(755, frappe, frappe) %{_localstatedir}/frappe-bench/apps
%dir %attr(755, frappe, frappe) %{_localstatedir}/frappe-bench/config
%dir %attr(755, frappe, frappe) %{_localstatedir}/frappe-bench/logs
%dir %attr(755, frappe, frappe) %{_localstatedir}/frappe-bench/sites

%files doc
%doc CONTRIBUTING.md attributions.md

%changelog
* Thu Aug 06 2015 William Moreno Reyes <williamjmorenor at gmail.com> 
- 5.3.0-2
- Fix #1251224
- Create -doc and -libs sub packages

* Tue Aug 04 2015 William Moreno Reyes <williamjmorenor at gmail.com> 
- 5.3.0-1
- Update to 5.3.0
- Update Unit File

* Fri Jul 31 2015 William Moreno Reyes <williamjmorenor at gmail.com> 
- 5.2.2-2
- Update Python macros

* Wed Jul 29 2015 William Moreno Reyes <williamjmorenor at gmail.com> 
- 5.1.5-1
- Update to v5.1.5 release
- Fix npm(Flop) requires

* Mon Jul 27 2015 William Moreno Reyes <williamjmorenor at gmail.com> 
- 5.1.3-4
- Initial Import of #1228942
